package core.notevault.sync;
import android.content.Context;
import androidx.annotation.NonNull;
import androidx.work.Worker;
import androidx.work.WorkerParameters;
import core.notevault.data.MusicDatabase;

import core.notevault.sync.synchronisation.*;
import core.notevault.sync.synchronisation.songs.SongSyncWorker;


public class SyncWorker extends Worker{
    private SongSyncWorker songSyncWorker;
    public SyncWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        SyncService syncService = ApiClient.getRetrofitInstance(context).create(SyncService.class);
        MusicDatabase musicDatabase = MusicDatabase.getDatabase(context);
        this.songSyncWorker = new SongSyncWorker(syncService, musicDatabase.musicNoteDao(), context);
    }

    @NonNull
    @Override
    public Result doWork() {
        try {
            songSyncWorker.syncSongCreations();
            songSyncWorker.syncSongModifications();
            songSyncWorker.syncSongDeletions();
            songSyncWorker.uploadNoteSheets();
            songSyncWorker.fetchModifiedSongs();
            return Result.success();
        } catch (Exception e) {
            e.printStackTrace();
            return Result.failure();
        }
    }


}
